==> GyverLamp2-0.1.3.tar.gz: GyverLamp2-0.1.3/GyverLamp2/config.py <==
DEFAULT_SETTINGS_DATA = {'brightness': '100', 'adc': '1', 'min_brightness': '0', 'max_brightness': '255',
                         'regime_change': '0', 'random_order_modes': '0', 'shift_period': '1', 'strip_type': '2',
                         'maximal_current': '15', 'work_hours_from': '0', 'work_hours_to': '0',
                         'matrix_orientation': '1', 'height': '16', 'width': '16', 'gmt': '16',
                         'city_id': '524901', 'mqtt_state': '0', 'mqtt_id': 'alexLamp123',
                         'mqtt_host': 'broker.mqttdashboard.com', 'mqtt_port': '1883', 'mqtt_login': 'gyver',
                         'mqtt_pass': '123456'}

DAYS_OF_THE_WEEK = {'1': 'пн', '2': 'вт', '3': 'ср', '4': 'чт', '5': 'пт', '6': 'сб', '7': 'вс'}

CONTROL_TYPES = {'0': 'выключить', '1': 'включить', '2': 'минимальная яркость',
                 '3': 'максимальная яркость', '4': 'режим назад', '5': 'режим вперёд',
                 '6': 'установить режим', '7': 'установить режим WiFi',
                 '8': 'смена роли', '9': 'смена группы', '10': 'установка WiFi',
                 '11': 'перезагрузить', '12': 'обновить прошивку',
                 '13': 'таймер выключения'}

NAME_SETTINGS = ['яркость', 'режим АЦП', 'мин яркость', 'макс яркость', 'смена режимов', 'случайный порядок',
                 'период смены', 'тип лампы', 'макс ток', 'часы работы от', 'часы работы до', 'ориентация матрицы',
                 'длины', 'ширина', 'часовой пояс', 'id города', 'mqtt состояния', 'mqtt id', 'mqtt host',
                 'mqtt port', 'mqtt login', 'mqtt pass']

TYPE_EFFECTS = {'1': 'перлин', '2': 'цвет', '3': 'смена', '4': 'градиент', '5': 'частицы', '6': 'огонь',
                '7': 'погода'}

TYPE_PALLETES = {'1': 'Кастом', '2': 'Тепловая', '3': 'Огненная', '4': 'Лава', '5': 'Вечеринка', '6': 'Радуга',
                 '7': 'Полосатая радуга', '8': 'Облака', '9': 'Океан', '10': 'Лес', '11': 'Закат', '12': 'Полиция',
                 '13': 'Оптимус Прайм', '14': 'Тёплая лава', '15': 'Холодная лава', '16': 'Горячая лава',
                 '17': 'Розовая лава', '18': 'Уютный', '19': 'Киберпанк', '20': 'Девчачая', '21': 'Рождество',
                 '22': 'Кислота', '23': 'Синий дым', '24': 'Жвачка', '25': 'Леопард', '26': 'Аврора'}

==> GyverLamp2-0.1.4.tar.gz: GyverLamp2-0.1.4/GyverLamp2/config.py <==
DEFAULT_SETTINGS_DATA = {'brightness': '100', 'adc': '1', 'min_brightness': '0', 'max_brightness': '255',
                         'regime_change': '0', 'random_order_modes': '0', 'shift_period': '1', 'strip_type': '2',
                         'maximal_current': '15', 'work_hours_from': '0', 'work_hours_to': '0',
                         'matrix_orientation': '1', 'height': '16', 'width': '16', 'gmt': '16',
                         'city_id': '524901', 'mqtt_state': '0', 'mqtt_id': 'alexLamp123',
                         'mqtt_host': 'broker.mqttdashboard.com', 'mqtt_port': '1883', 'mqtt_login': 'gyver',
                         'mqtt_pass': '123456'}

DEFAULT_EFFECTS_DATA = {'count_effets': '1', 'type_effect': '1', 'fade_brightness': '1', 'brightness': '255',
                        'adv_mode': '1', 'effect_react': '1', 'min_signal': '0', 'max_signal': '255',
                        'speed': '105', 'scale': '255', 'from_center': '0', 'color': '255', 'random': '0'}

DAYS_OF_THE_WEEK = {'1': 'пн', '2': 'вт', '3': 'ср', '4': 'чт', '5': 'пт', '6': 'сб', '7': 'вс'}

CONTROL_TYPES = {'0': 'выключить', '1': 'включить', '2': 'минимальная яркость',
                 '3': 'максимальная яркость', '4': 'режим назад', '5': 'режим вперёд',
                 '6': 'установить режим', '7': 'установить режим WiFi',
                 '8': 'смена роли', '9': 'смена группы', '10': 'установка WiFi',
                 '11': 'перезагрузить', '12': 'обновить прошивку',
                 '13': 'таймер выключения'}

NAME_SETTINGS = ['яркость', 'режим АЦП', 'мин яркость', 'макс яркость', 'смена режимов', 'случайный порядок',
                 'период смены', 'тип лампы', 'макс ток', 'часы работы от', 'часы работы до', 'ориентация матрицы',
                 'длины', 'ширина', 'часовой пояс', 'id города', 'mqtt состояния', 'mqtt id', 'mqtt host',
                 'mqtt port', 'mqtt login', 'mqtt pass']

TYPE_EFFECTS = ['перлин', 'цвет', 'смена', 'градиент', 'частицы', 'огонь', 'погода']

TYPE_PALLETES = ['Кастом', 'Тепловая', 'Огненная', 'Лава', 'Вечеринка', 'Радуга', 'Полосатая радуга', 'Облака', 'Океан',
                 'Лес', 'Закат', 'Полиция', 'Оптимус Прайм', 'Тёплая лава', 'Холодная лава', 'Горячая лава',
                 'Розовая лава', 'Уютный', 'Киберпанк', 'Девчачая', 'Рождество', 'Кислота', 'Синий дым', 'Жвачка',
                 'Леопард', 'Аврора']
